==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Members_List/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","Email");
define("_REALNAME","Prawdziwa nazwa");
define("_FUNCTIONS","Funkcje");
define("_PREVIOUS","Poprzednia strona");
define("_MEMBERSLIST","Lista zarejestrowanych uytkownikw");
define("_GREETINGS","Pozdrowienia dla ostatnio zarejestrowanego uytkownika:");
define("_SORTBY","Sortowane wedug:");
define("_MNICKNAME","pseudonim");
define("_MREALNAME","prawdziwe imi");
define("_MEMAIL","email");
define("_MURL","adres");
define("_ONLINEREG","Aktualnie zarejestrowanych uytkownikw online:");
define("_WEHAVE","Mamy");
define("_MREGISTERED","dotychczas zarejestrowanych uytkownikw. Teraz jest");
define("_MREGONLINE","zarejestrowanych uytkownikw online.");
define("_REGSOFAR","dotychczas zarejestrowanych uytkownikw.");
define("_USERSFOUND","znalezionych uytkownikw dla");
define("_USERSSHOWN","pokazanych uytkownikw");
define("_NOMEMBERS","Brak zarejestrowanych uytkownikw dla");
define("_PAGES","Strony");
define("_HOMEPAGE","Strona WWW");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Members_List/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","Email");
define("_REALNAME","Prawdziwa nazwa");
define("_FUNCTIONS","Funkcje");
define("_PREVIOUS","Poprzednia strona");
define("_MEMBERSLIST","Lista zarejestrowanych uytkownikw");
define("_GREETINGS","Pozdrowienia dla ostatnio zarejestrowanego uytkownika:");
define("_SORTBY","Sortowane wedug:");
define("_MNICKNAME","pseudonim");
define("_MREALNAME","prawdziwe imi");
define("_MEMAIL","email");
define("_MURL","adres");
define("_ONLINEREG","Aktualnie zarejestrowanych uytkownikw online:");
define("_WEHAVE","Mamy");
define("_MREGISTERED","dotychczas zarejestrowanych uytkownikw. Teraz jest");
define("_MREGONLINE","zarejestrowanych uytkownikw online.");
define("_REGSOFAR","dotychczas zarejestrowanych uytkownikw.");
define("_USERSFOUND","znalezionych uytkownikw dla");
define("_USERSSHOWN","pokazanych uytkownikw");
define("_NOMEMBERS","Brak zarejestrowanych uytkownikw dla");
define("_PAGES","Strony");
define("_HOMEPAGE","Strona WWW");

?>
